;; Generated package description from rainbow-mode.el  -*- no-byte-compile: t -*-
(define-package "rainbow-mode" "1.0.6.0.20220501.92311" "Colorize color names in buffers" 'nil :commit "ac68593018ef3555e64ea592d72334f4e3e39209" :url "https://elpa.gnu.org/packages/rainbow-mode.html" :authors '(("Julien Danjou" . "julien@danjou.info")) :maintainer '("Julien Danjou" . "julien@danjou.info") :keywords '("faces"))
